@@ -1,5 +1,6 @@
 module Sidekiq
   module Paginator
+
     def page(key, pageidx=1, page_size=25, opts=nil)
       current_page = pageidx.to_i < 1 ? 1 : pageidx.to_i
       pageidx = current_page - 1
@@ -22,19 +23,20 @@ module Sidekiq
               conn.zrange(key, starting, ending, :with_scores => true)
             end
           end
+          [current_page, total_size, items]
         when 'list'
           total_size, items = conn.multi do
             conn.llen(key)
             conn.lrange(key, starting, ending)
           end
+          [current_page, total_size, items]
         when 'none'
-          return [1, 0, []]
+          [1, 0, []]
         else
           raise "can't page a #{type}"
         end
       end
-
-      [current_page, total_size, items]
     end
+
   end
 end
